load_from_data — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# load_from_data

Poscar.load_from_data(direct_positions: np.ndarray, lattice: np.ndarray, elements: List[str])

  It loades the Poscar class with essencial data.

  Parameters:

    - direct_pos (np.ndarray) – atomic positions in direct (fractional) coordiantes. Size [Natoms:3]

    - lattice (np.ndarray) – Lattice vectors [3:3], in Angstroms

    - elements (List[str]) – A list of atomic symbols, with the same order as the direct_positions